@@ -69,12 +69,18 @@ class System:
     def get(self):
         """"""
         ip_address = subprocess.check_output(["hostname", "-I"]).split()[0].decode()
-        addresses = []
+        try:
+            with open("/var/lib/tor/main/hostname") as fp:
+                onion = fp.read()
+        except FileNotFoundError:
+            onion = None
+        domains = []
         webint_metadata = importlib.metadata.metadata("webint")
         webint_versions = get_versions("webint")
         return app.view.index(
             ip_address,
-            addresses,
+            onion,
+            domains,
             web.tx.app.cfg,
             web.tx.app,
             web.get_apps(),
